package com.ruoyi.szxc.service.impl;

import com.ruoyi.common.annotation.DataScope;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.szxc.domain.SzxcButie;
import com.ruoyi.szxc.mapper.SzxcButieMapper;
import com.ruoyi.szxc.service.ISzxcButieService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 补贴管理Service业务层处理
 * 
 * @author hs
 * @date 2024-03-20
 */
@Service
public class SzxcButieServiceImpl implements ISzxcButieService 
{
    @Autowired
    private SzxcButieMapper szxcButieMapper;

    /**
     * 查询补贴管理
     * 
     * @param id 补贴管理主键
     * @return 补贴管理
     */
    @Override
    public SzxcButie selectSzxcButieById(Long id)
    {
        return szxcButieMapper.selectSzxcButieById(id);
    }

    /**
     * 查询补贴管理列表
     * 
     * @param szxcButie 补贴管理
     * @return 补贴管理
     */
    @Override
    @DataScope(deptAlias = "b")
    public List<SzxcButie> selectSzxcButieList(SzxcButie szxcButie)
    {
        return szxcButieMapper.selectSzxcButieList(szxcButie);
    }

    /**
     * 新增补贴管理
     * 
     * @param szxcButie 补贴管理
     * @return 结果
     */
    @Override
    public int insertSzxcButie(SzxcButie szxcButie)
    {
        szxcButie.setCreateTime(DateUtils.getNowDate());
        return szxcButieMapper.insertSzxcButie(szxcButie);
    }

    /**
     * 修改补贴管理
     * 
     * @param szxcButie 补贴管理
     * @return 结果
     */
    @Override
    public int updateSzxcButie(SzxcButie szxcButie)
    {
        szxcButie.setUpdateTime(DateUtils.getNowDate());
        return szxcButieMapper.updateSzxcButie(szxcButie);
    }

    /**
     * 批量删除补贴管理
     * 
     * @param ids 需要删除的补贴管理主键
     * @return 结果
     */
    @Override
    public int deleteSzxcButieByIds(Long[] ids)
    {
        return szxcButieMapper.deleteSzxcButieByIds(ids);
    }

    /**
     * 删除补贴管理信息
     * 
     * @param id 补贴管理主键
     * @return 结果
     */
    @Override
    public int deleteSzxcButieById(Long id)
    {
        return szxcButieMapper.deleteSzxcButieById(id);
    }
}
